import { Callback, Options, Stats } from "../types-public";
/**
 * Enhanced `fs.readdir()` asynchronous interface.
 */
export interface ReaddirAsync {
    /**
     * Aynchronous `readdir()` that returns an array of path strings.
     */
    (dir: string, options?: Options): Promise<string[]>;
    /**
     * Aynchronous `readdir()` that returns an array of path strings via a callback.
     */
    (dir: string, callback: Callback<string[]>): void;
    /**
     * Aynchronous `readdir()` that returns an array of path strings via a callback.
     */
    (dir: string, options: Options | undefined, callback: Callback<string[]>): void;
    stat: {
        /**
         * Asynchronous `readdir()` that returns an array of `Stats` objects.
         */
        (dir: string, options?: Options): Promise<Stats[]>;
        /**
         * Asynchronous `readdir()` that returns an array of `Stats` objects via a callback.
         */
        (dir: string, callback: Callback<Stats[]>): void;
        /**
         * Asynchronous `readdir()` that returns an array of `Stats` objects via a callback.
         */
        (dir: string, options: Options | undefined, callback: Callback<Stats[]>): void;
    };
}
declare const async: ReaddirAsync;
export { async };
/**
 * Aynchronous `readdir()` (accepts an error-first callback or returns a `Promise`).
 * Results are an array of path strings.
 */
export declare function readdirAsync(dir: string, options?: Options): Promise<string[]>;
export declare function readdirAsync(dir: string, callback: Callback<string[]>): void;
export declare function readdirAsync(dir: string, options: Options | undefined, callback: Callback<string[]>): void;
/**
 * Aynchronous `readdir()` (accepts an error-first callback or returns a `Promise`).
 * Results are an array of `Stats` objects.
 */
export declare function readdirAsyncStat(dir: string, options?: Options): Promise<Stats[]>;
export declare function readdirAsyncStat(dir: string, callback: Callback<Stats[]>): void;
export declare function readdirAsyncStat(dir: string, options: Options | undefined, callback: Callback<Stats[]>): void;
