"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable: promise-function-async
const fs = require("fs");
const directory_reader_1 = require("../directory-reader");
const for_each_1 = require("./for-each");
const asyncFacade = { fs, forEach: for_each_1.asyncForEach };
const async = readdirAsync;
exports.async = async;
async.stat = readdirAsyncStat;
function readdirAsync(dir, options, callback) {
    return readdirAsyncInternal(dir, options, callback, {});
}
exports.readdirAsync = readdirAsync;
function readdirAsyncStat(dir, options, callback) {
    return readdirAsyncInternal(dir, options, callback, { stats: true });
}
exports.readdirAsyncStat = readdirAsyncStat;
/**
 * Returns the buffered output from an asynchronous `DirectoryReader`,
 * via an error-first callback or a `Promise`.
 */
function readdirAsyncInternal(dir, options, callback, behavior) {
    if (typeof options === "function") {
        callback = options;
        options = undefined;
    }
    let promise = new Promise((resolve, reject) => {
        let results = [];
        let reader = new directory_reader_1.DirectoryReader(dir, options, behavior, asyncFacade);
        let stream = reader.stream;
        stream.on("error", (err) => {
            reject(err);
            stream.pause();
        });
        stream.on("data", (result) => {
            results.push(result);
        });
        stream.on("end", () => {
            resolve(results);
        });
    });
    if (callback) {
        promise.then((results) => callback(null, results), (err) => callback(err, undefined));
    }
    else {
        return promise;
    }
}
//# sourceMappingURL=index.js.map