import { Options, Stats } from "../types-public";
/**
 * Enhanced `fs.readdir()` async iterator interface.
 */
export interface ReaddirIterator {
    /**
     * Aynchronous `readdir()` that returns an `AsyncIterableIterator` (an object that implements
     * both the `AsyncIterable` and `AsyncIterator` interfaces) that yields path strings.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Iterators_and_Generators
     */
    (dir: string, options?: Options): AsyncIterableIterator<string>;
    /**
     * Aynchronous `readdir()` that returns an `AsyncIterableIterator` (an object that implements
     * both the `AsyncIterable` and `AsyncIterator` interfaces) that yields `Stats` objects.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Iterators_and_Generators
     */
    stat(dir: string, options?: Options): AsyncIterableIterator<Stats>;
}
declare const iterator: ReaddirIterator;
export { iterator };
/**
 * Aynchronous `readdir()` that returns an `AsyncIterableIterator` (an object that implements
 * both the `AsyncIterable` and `AsyncIterator` interfaces) that yields path strings.
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Iterators_and_Generators
 */
export declare function readdirIterator(dir: string, options?: Options): AsyncIterableIterator<string>;
/**
 * Aynchronous `readdir()` that returns an `AsyncIterableIterator` (an object that implements
 * both the `AsyncIterable` and `AsyncIterator` interfaces) that yields `Stats` objects.
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Iterators_and_Generators
 */
export declare function readdirIteratorStat(dir: string, options?: Options): AsyncIterableIterator<Stats>;
