/// <reference types="node" />
import { Readable } from "stream";
import { Options } from "../types-public";
/**
 * Enhanced `fs.readdir()` streaming interface.
 */
export interface ReaddirStream {
    /**
     * Aynchronous `readdir()` that returns a `ReadableStream` (which is also an `EventEmitter`).
     * All stream data events ("data", "file", "directory", "symlink") are passed a path string.
     */
    (dir: string, options?: Options): Readable;
    /**
     * Aynchronous `readdir()` that returns a `ReadableStream` (which is also an `EventEmitter`)
     * All stream data events ("data", "file", "directory", "symlink") are passed a `Stats` object.
     */
    stat(dir: string, options?: Options): Readable;
}
declare const stream: ReaddirStream;
export { stream };
/**
 * Aynchronous `readdir()` that returns a `ReadableStream` (which is also an `EventEmitter`).
 * All stream data events ("data", "file", "directory", "symlink") are passed a path string.
 */
export declare function readdirStream(dir: string, options?: Options): Readable;
/**
 * Aynchronous `readdir()` that returns a `ReadableStream` (which is also an `EventEmitter`)
 * All stream data events ("data", "file", "directory", "symlink") are passed a `Stats` object.
 */
export declare function readdirStreamStat(dir: string, options?: Options): Readable;
