"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const for_each_1 = require("../async/for-each");
const directory_reader_1 = require("../directory-reader");
const streamFacade = { fs, forEach: for_each_1.asyncForEach };
const stream = readdirStream;
exports.stream = stream;
stream.stat = readdirStreamStat;
/**
 * Aynchronous `readdir()` that returns a `ReadableStream` (which is also an `EventEmitter`).
 * All stream data events ("data", "file", "directory", "symlink") are passed a path string.
 */
function readdirStream(dir, options) {
    return readdirStreamInternal(dir, options, {});
}
exports.readdirStream = readdirStream;
/**
 * Aynchronous `readdir()` that returns a `ReadableStream` (which is also an `EventEmitter`)
 * All stream data events ("data", "file", "directory", "symlink") are passed a `Stats` object.
 */
function readdirStreamStat(dir, options) {
    return readdirStreamInternal(dir, options, { stats: true });
}
exports.readdirStreamStat = readdirStreamStat;
/**
 * Returns the `ReadableStream` of an asynchronous `DirectoryReader`.
 */
function readdirStreamInternal(dir, options, behavior) {
    let reader = new directory_reader_1.DirectoryReader(dir, options, behavior, streamFacade);
    return reader.stream;
}
//# sourceMappingURL=index.js.map