"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const directory_reader_1 = require("../directory-reader");
const for_each_1 = require("./for-each");
const fs_1 = require("./fs");
const syncFacade = { fs: fs_1.syncFS, forEach: for_each_1.syncForEach };
const sync = readdirSync;
exports.sync = sync;
sync.stat = readdirSyncStat;
/**
 * Synchronous `readdir()` that returns an array of string paths.
 */
function readdirSync(dir, options) {
    return readdirSyncInternal(dir, options, {});
}
exports.readdirSync = readdirSync;
/**
 * Synchronous `readdir()` that returns results as an array of `Stats` objects
 */
function readdirSyncStat(dir, options) {
    return readdirSyncInternal(dir, options, { stats: true });
}
exports.readdirSyncStat = readdirSyncStat;
/**
 * Returns the buffered output from a synchronous `DirectoryReader`.
 */
function readdirSyncInternal(dir, options, behavior) {
    let reader = new directory_reader_1.DirectoryReader(dir, options, behavior, syncFacade);
    let stream = reader.stream;
    let results = [];
    let data = stream.read();
    while (data !== null) {
        results.push(data);
        data = stream.read();
    }
    return results;
}
//# sourceMappingURL=index.js.map